package com.jiuqi.grid;

import com.jiuqi.util.StringUtils;
import com.jiuqi.util.chinese.ChineseDouble;
import java.io.Serializable;
import java.text.DecimalFormat;

public class NumberCellProperty implements NumberCellPropertyIntf, CellDataProcessorIntf, Serializable {
   protected CellDataPropertyIntf cellDataProperty;

   public NumberCellProperty(CellDataPropertyIntf dataProperty) {
      this.cellDataProperty = dataProperty;
   }

   public NumberCellProperty(GridCell cell) {
      this((CellDataPropertyIntf)(new CellDataProperty(cell)));
   }

   public CellDataPropertyIntf getCellDataProperty() {
      return this.cellDataProperty;
   }

   public int getDecimal() {
      return this.cellDataProperty.getDataFlag();
   }

   public void setDecimal(int value) {
      if (value <= 15) {
         if (value < 0) {
            value = 0;
         }

         this.cellDataProperty.setDataFlag((byte)value);
      } else {
         throw new IllegalArgumentException("错误设置了数字的小数位数，应该在0-15之间！");
      }
   }

   public int getPrecision() {
      return this.cellDataProperty.getDataProperty() & 31;
   }

   public void setPrecision(int value) {
      if (value >= 0 && value <= 32) {
         int data = value & 31;
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -32 | data));
      } else {
         throw new IllegalArgumentException("错误设置了数字的精度，应该在0-32之间！");
      }
   }

   public boolean getThoundsMark() {
      return (this.cellDataProperty.getDataProperty() & '耀') != 0;
   }

   public void setThoundsMarks(boolean value) {
      if (value) {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | '耀'));
      } else {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -32769));
      }

   }

   public boolean getBracketNegative() {
      return (this.cellDataProperty.getDataProperty() & 16384) != 0;
   }

   public void setBracketNegative(boolean value) {
      if (value) {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | 16384));
      } else {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -16385));
      }

   }

   public boolean getWarningNegative() {
      return (this.cellDataProperty.getDataProperty() & 8192) != 0;
   }

   public void setWarningNegative(boolean value) {
      if (value) {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | 8192));
      } else {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -8193));
      }

   }

   public boolean getChineseNumber() {
      return (this.cellDataProperty.getDataProperty() & 4096) != 0;
   }

   public void setChineseNumber(boolean value) {
      if (value) {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | 4096));
      } else {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -4097));
      }

   }

   public boolean getBigChineseChar() {
      return (this.cellDataProperty.getDataProperty() & 2048) != 0;
   }

   public void setBigChineseChar(boolean value) {
      if (value) {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | 2048));
      } else {
         this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -2049));
      }

   }

   public boolean getIsPercent() {
      if (this.cellDataProperty.getDataType() == 2) {
         return (this.cellDataProperty.getDataProperty() & 1024) != 0;
      } else {
         return false;
      }
   }

   public void setIsPercent(boolean value) {
      if (this.cellDataProperty.getDataType() == 2) {
         if (value) {
            this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() | 1024));
         } else {
            this.cellDataProperty.setDataProPerty((short)(this.cellDataProperty.getDataProperty() & -1025));
         }
      }

   }

   public String getEditText(String storeText) {
      return storeText;
   }

   public String getShowText(String storeText) {
      if (storeText == null) {
         throw new IllegalArgumentException("不能解析指向null的字符串为数字！");
      } else {
         String showText = null;
         if (storeText == "") {
            showText = "";
         } else {
            storeText = StringUtils.eliminate(storeText, ',');

            double value;
            try {
               value = Double.parseDouble(storeText);
            } catch (NumberFormatException var10) {
               return storeText;
            }

            boolean isNegtive = value < 0.0;
            boolean isPercent = this.getIsPercent();
            boolean showThoundsMark = this.getThoundsMark();
            if (isNegtive) {
               value = -value;
            }

            if (isPercent && !showThoundsMark) {
               value *= 100.0;
               this.setDecimal(this.getDecimal() - 2);
            } else if (isPercent && showThoundsMark) {
               value *= 1000.0;
               this.setDecimal(this.getDecimal() - 3);
            }

            int decimal = this.getDecimal();
            if (decimal == 15) {
               int decimal = false;
            }

            value = trimDouble(value, this.getDecimal());
            if (!this.getChineseNumber()) {
               showText = formatNumberString(value, this.getDecimal(), this.getThoundsMark());
               if (isPercent && !showThoundsMark) {
                  showText = showText + "%";
               }

               if (isPercent && showThoundsMark) {
                  showText = showText + "‰";
               }

               if (isNegtive) {
                  if (this.getBracketNegative()) {
                     showText = "(" + showText + ")";
                  } else {
                     showText = "-" + showText;
                  }
               }
            } else {
               ChineseDouble cnDouble;
               if (isPercent && !showThoundsMark) {
                  cnDouble = new ChineseDouble(value / 100.0);
                  showText = cnDouble.getPercentForm(this.getDecimal(), true, this.getBigChineseChar());
               }

               if (isPercent && showThoundsMark) {
                  cnDouble = new ChineseDouble(value / 1000.0);
                  showText = cnDouble.getPermillageForm(this.getDecimal(), true, this.getBigChineseChar());
               }

               if (!isPercent) {
                  cnDouble = new ChineseDouble(value);
                  if (!showThoundsMark) {
                     showText = cnDouble.chineseValue(this.getDecimal(), false, this.getBigChineseChar());
                  } else {
                     showText = cnDouble.chineseValue(this.getDecimal(), true, this.getBigChineseChar());
                  }
               }

               if (isNegtive) {
                  showText = "（负）" + showText;
               }
            }

            if (isPercent) {
               this.setDecimal(this.getDecimal() + (showThoundsMark ? 3 : 2));
            }
         }

         return showText;
      }
   }

   public String parseEditText(String editText) {
      double value = Double.parseDouble(editText);
      return formatNumberString(value, this.getDecimal(), false);
   }

   public String parseShowText(String showText) {
      String value = "";
      if (!this.getChineseNumber()) {
         value = showText;
      } else {
         try {
            value = ChineseDouble.valueOf(showText);
         } catch (Exception var5) {
            throw new IllegalArgumentException("中文数值有错误，解析失败");
         }
      }

      double dbValue = Double.parseDouble(value);
      return formatNumberString(dbValue, this.getDecimal(), this.getThoundsMark());
   }

   private static double trimDouble(double source, int frcLength) {
      if (frcLength < 0) {
         frcLength = 0;
      }

      int multiplier = (int)Math.exp(Math.log(10.0) * (double)frcLength);
      double temp = (double)Math.round(source * (double)multiplier);
      double des = temp / (double)multiplier;
      return des;
   }

   private static String formatNumberString(double value, int decimal, boolean thoundsMark) {
      DecimalFormat df = new DecimalFormat();
      df.setGroupingUsed(false);
      if (thoundsMark) {
         df.setGroupingSize(3);
         df.setGroupingUsed(true);
      }

      if (decimal >= 0) {
         df.setMaximumFractionDigits(decimal);
         df.setMinimumFractionDigits(decimal);
      }

      return df.format(value);
   }
}
